Summary: Kernel-based Virtual Machine
Name: kvm
Version: 35
Release: 1
License: GPL
Group: Development/Tools
URL: http://kvm.sf.net
Source0: http://download.sourceforge.net/sourceforge/kvm/kvm-%{version}.tar.gz
Source1: kvm.modules
Patch0: kvm-19-defaults.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: SDL-devel 
# qemu doesn't build with gcc 4.x
BuildRequires: compat-gcc-34 
BuildRequires: zlib-devel 
BuildRequires: e2fsprogs-devel
# for the docs
BuildRequires: texi2html
# kvm kernel side is only x86/x86_64 as that's where the hardware is
ExclusiveArch: %{ix86} x86_64
Requires: initscripts >= 8.08-1

%description
KVM (for Kernel-based Virtual Machine) is a full virtualization solution 
for Linux on x86 hardware. 

Using KVM, one can run multiple virtual machines running unmodified Linux 
or Windows images. Each virtual machine has private virtualized hardware: 
a network card, disk, graphics adapter, etc.

%prep
%setup -q
%patch0 -p1 -b .defaults

%build
./configure --with-patched-kernel --qemu-cc=gcc34 --kerneldir=$(pwd)/kernel --prefix=%{_prefix}
# we need to install the data bits in a different path
sed -i 's/CONFIG_QEMU_SHAREDIR \"\/usr\/share\/qemu\"/CONFIG_QEMU_SHAREDIR \"\/usr\/share\/kvm\"/' qemu/config-host.h
sed -i 's/datadir=\/usr\/share\/qemu/datadir=\/usr\/share\/kvm/' qemu/config-host.mak

# we can't use RPM_OPT_FLAGS for the same reasons as qemu (#208026) for the
# qemu bits.  so let's set it for the other pieces.  this requires some
# manual keeping up of what is in the kvm tree.
sed -i 's/CFLAGS =/CFLAGS +=/' user/Makefile
echo "CFLAGS=$RPM_OPT_FLAGS" >> user/config.mak
make %{?_smp_mflags} 


%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

# we have to have our own copies of the bios/keymaps due to incompat with
# qemu 0.9.  include the man page
mv $RPM_BUILD_ROOT/%{_mandir}/man1/qemu.1* $RPM_BUILD_ROOT/%{_mandir}/man1/qemu-kvm.1
rm -rf $RPM_BUILD_ROOT/%{_mandir}/man*/qemu-img* $RPM_BUILD_ROOT/%{_docdir}
rm -f $RPM_BUILD_ROOT/%{_bindir}/qemu-img
# no shared lib, static libs
rm -fr $RPM_BUILD_ROOT/%{_includedir} $RPM_BUILD_ROOT/%{_libdir}

mv $RPM_BUILD_ROOT/%{_bindir}/qemu* $RPM_BUILD_ROOT/%{_bindir}/qemu-kvm

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules
install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules/kvm.modules

%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%{_bindir}/qemu-kvm
%{_mandir}/man*/*
%{_datadir}/kvm
%{_sysconfdir}/sysconfig/modules/kvm.modules

%changelog
* Mon Aug 20 2007 Daniel de Kok <daniel@centos.org> - 35-1
- update to kvm-35

* Wed Jul 28 2007 Daniel de Kok <daniel@centos.org> - 33-1
- update to kvm-33

* Wed Jul 18 2007 Daniel de Kok <daniel@centos.org> - 29-1
- update to kvm-29

* Mon Jun 18 2007 Daniel de Kok <daniel@centos.org> - 28-1
- update to kvm-28

* Wed May 16 2007 Jeremy Katz <katzj@redhat.com> - 24-1
- update to kvm-24

* Wed Apr 25 2007 Jeremy Katz <katzj@redhat.com> - 19-2
- fix kernel and ramdisk being specified on the command line (#237879)

* Tue Apr 17 2007 Jeremy Katz <katzj@redhat.com> - 19-1
- update to kvm-19
- use rtl8139 as the default nic emulation instead of ne2k_pci (#236790)

* Mon Mar 26 2007 Jeremy Katz <katzj@redhat.com> - 15-2
- add file so that kvm modules get loaded on boot

* Wed Mar  7 2007 Jeremy Katz <katzj@redhat.com> - 15-1
- update to kvm-15

* Mon Feb 26 2007 Jeremy Katz <katzj@redhat.com> - 14-2
- use default optflags for non-qemu pieces (#230012)

* Fri Feb 23 2007 Jeremy Katz <katzj@redhat.com> - 14-1
- update to kvm-14
- note: this requires a kernel that's 2.6.21-rc1 or newer

* Mon Feb 19 2007 Jeremy Katz <katzj@redhat.com> - 12-3
- add the buildrequires for the docs to build

* Mon Feb 19 2007 Jeremy Katz <katzj@redhat.com> - 12-2
- include bios and keymaps in the kvm package since we need a slightly 
  different version for kvm now
- include man page

* Fri Jan 26 2007 Jeremy Katz <katzj@redhat.com> - 12-1
- update to kvm-12
- add qemu patch for better ATAPI DMA support (which works with ata_piix)

* Fri Jan 19 2007 Jeremy Katz <katzj@redhat.com> - 11-1
- update to kvm-11

* Fri Jan  5 2007 Jeremy Katz <katzj@redhat.com> - 9-1
- update to kvm-9

* Wed Jan  3 2007 Jeremy Katz <katzj@redhat.com> - 7-4
- actually build without -devel...

* Wed Dec 20 2006 Jeremy Katz <katzj@redhat.com> - 7-3
- remove the -devel subpackage since there's no shared lib upstream yet
- direct download link for source 

* Tue Dec 19 2006 Jeremy Katz <katzj@redhat.com> - 7-2
- BR e2fsprogs-devel

* Tue Dec 19 2006 Jeremy Katz <katzj@redhat.com> - 7-1
- Initial build 

